// This is a script that is called by ePubCrawler to calculate custom 
// placeholders in ExtendScript. You need to have some experience
// with InDesign's ExtendScript before this info will make sense.
//
// These formulas/placeholders can be defined for different contexts:
//
// When these formulas are called, they receive an object parameter
// which contains the context info the formula might need to do its
// job.
//
// The context also contains all applicable system-defined placeholders 
// (e.g. FRAME_XPOS_PIXEL)
//
// Document level:
// 
// context = 
// {
//   doc: ... current InDesign Document object ...
// }
//
// Page level:
//
// context = 
// {
//   doc: ... current InDesign Document object ...
//   page: ...current InDesign page object...   
// }
//
// Frame level:
//
// context = 
// {
//   doc: ... current InDesign Document object ...
//   page: ...current InDesign page object...
//   frame: ... current InDesign page item object ...
// }
//
// Paragraph level:
//
// context = 
// {
//   doc: ... current InDesign Document object ...
//   page: ... current InDesign page object...
//   frame: ... current InDesign page item object ...
//   paragraph: ... current InDesign paragraph object ...
// }
//
// Paragraph Style Level:
//
// context = 
// {
//   doc: ... current InDesign Document object ...
//   paragraphStyle: ... current InDesign Paragrah Style object ...
// }
//
// Character Style Level:
//
// context = 
// {
//   doc: ... current InDesign Document object ...
//   characterStyle: ... current InDesign Character Style object ...
// }

TODAYS_DATE = function(context)
{
    return new Date().toString();
}

TEXT_FRAME_VISIBLE_CSS = function(context)
{
    // See config.ini 'imageHandling'
    if (context.config.imagehandling == 4)
    {
        return "hidden";
    }
    else
    {
        return "visible";
    }
}

IMAGE_FRAME_VISIBLE_CSS = function(context)
{
    // See config.ini 'imageHandling'
    if ((context.config.imagehandling == 4 || context.config.imagehandling == 3) && context.FRAME_TYPE != "BACKGROUND")
    {
        return "hidden";
    }
    else
    {
        return "visible";
    }
}

PAGE_STYLE_SHEET_REFERENCES = function(context)
{
    // See config.ini 'singleCSSFile'
    retVal = "<link href=\"template.css\" rel=\"stylesheet\" type=\"text/css\" />\n";
    if (! context.config.singlecssfile)
    {
        retVal += "\t\t<link href=\"" + context.PAGE_NAME + ".css\" rel=\"stylesheet\" type=\"text/css\" />\n";
    }

    return retVal;
}

FRAME_BORDER_MARGIN_PIXELS = function(context)
{
    return -Math.round(context.FRAME_BORDER_WEIGHT_PIXELS / 2.0);
}

FRAME_XPOS_PIXELS_WITH_INSET = function(context)
{
    return context.FRAME_XPOS_PIXELS + context.FRAME_INSET_LEFT_PIXELS;
}

FRAME_YPOS_PIXELS_WITH_INSET = function(context)
{
    return context.FRAME_YPOS_PIXELS + context.FRAME_INSET_TOP_PIXELS;
}

FRAME_WIDTH_PIXELS_WITH_INSET = function(context)
{
    return context.FRAME_WIDTH_PIXELS - context.FRAME_INSET_LEFT_PIXELS - context.FRAME_INSET_RIGHT_PIXELS - context.FRAME_BORDER_WEIGHT_PIXELS;
}

FRAME_HEIGHT_PIXELS_WITH_INSET = function(context)
{
    return context.FRAME_HEIGHT_PIXELS - context.FRAME_INSET_TOP_PIXELS - context.FRAME_INSET_BOTTOM_PIXELS - context.FRAME_BORDER_WEIGHT_PIXELS;
}

IMAGE_SCALED_WIDTH = function(context)
{
    return context.FRAME_IMAGE_WIDTH_PIXELS * 72 / context.IMAGE_EXPORT_DPI;
}

IMAGE_SCALED_HEIGHT = function(context)
{
    return context.FRAME_IMAGE_HEIGHT_PIXELS * 72 / context.IMAGE_EXPORT_DPI;
}
